==> mobroute-0.5.0.tar.gz: mobroute-v0.5.0/dbquery/loadconnections.go <==
package dbquery

import (
	"strings"

	"git.sr.ht/~mil/mobroute/dbt"
	"git.sr.ht/~mil/mobroute/util/utilfuncs"
	"github.com/jmoiron/sqlx"
)

// LoadConnections loads the valid connections for the given input timespan.
// Note input from/to seconds are expected to be in UTC timezone for the date
// and thus can be negative values themselves.
//
// Returned connections from_stop_drutctime and to_stop_drutctime are in
// UTC seconds and normalized in-query based on the source agency's timezone.
// This effectively "abstracts": timezone handling, multiday queries, and
// additionally using connections from different source timezones into a
// normalized format (returned connections existing as from/to UTC seconds
// relative to a given YYYYMMDD date).
func LoadConnections(
	DB *sqlx.DB, querySources []int, dateYYYYMMDD uint, fromUTCSeconds, toUTCSeconds int,
) (*[]dbt.Connection, error) {
	var (
		r      = []dbt.Connection{}
		params = append(
			[]any{dateYYYYMMDD, fromUTCSeconds, toUTCSeconds}, utilfuncs.Anyify(querySources)...,
		)
	)
	if query, err := utilfuncs.TemplateExecute(
		query_connections,
		map[string]any{
			"Table": "_cvconnd",
			"Columns": strings.Join(
				[]string{
					"conn_id", "trip_id",
					"from_stop_sequence", "from_stop_sidu", "from_stop_drutctime",
					"to_stop_sequence", "to_stop_sidu", "to_stop_drutctime",
				},
				",",
			),
			"SourcePlaceholders": strings.Join(utilfuncs.ArrayWithValue(len(querySources), "?"), ","),
		},
	); err != nil {
		return nil, err
	} else if err := queryToSlice(DB, query, params, &r); err != nil {
		return nil, err
	} else {
		return &r, nil
	}
}

==> mobroute-0.7.0.tar.gz: mobroute-v0.7.0/dbquery/loadconnections.go <==
package dbquery

import (
	"strings"

	"git.sr.ht/~mil/mobroute/dbt"
	"git.sr.ht/~mil/mobroute/util/utilfuncs"
	"github.com/jmoiron/sqlx"
)

// LoadConnections loads the valid connections for the given input timespan.
// Note input from/to seconds are expected to be in UTC timezone for the date
// and thus can be negative values themselves.
//
// Returned connections from_stop_drutctime and to_stop_drutctime are in
// UTC seconds and normalized in-query based on the feedid agency's timezone.
// This effectively "abstracts": timezone handling, multiday queries, and
// additionally using connections from different feedid timezones into a
// normalized format (returned connections existing as from/to UTC seconds
// relative to a given YYYYMMDD date).
func LoadConnections(
	DB *sqlx.DB, queryFeedIDs []int, tzToUTCDeltasMap map[string]int, dateYYYYMMDD uint, fromUTCSeconds, toUTCSeconds int,
) (*[]dbt.Connection, error) {
	var (
		r      = []dbt.Connection{}
		params = utilfuncs.Flatten([][]any{
			[]any{dateYYYYMMDD, fromUTCSeconds, toUTCSeconds},
			utilfuncs.Anyify(utilfuncs.KeyValues(tzToUTCDeltasMap)),
			utilfuncs.Anyify(queryFeedIDs),
		})
	)

	if query, err := utilfuncs.TemplateExecute(
		query_connections,
		map[string]any{
			"Table": "_cvconn",
			"Columns": strings.Join(
				[]string{
					"conn_id", "trip_id",
					"from_stop_sequence", "from_stop_sidu", "from_stop_drutctime",
					"to_stop_sequence", "to_stop_sidu", "to_stop_drutctime",
				},
				",",
			),
			"TzToDeltaSubquery":  strings.Join(utilfuncs.ArrayWithValue(len(tzToUTCDeltasMap), "select ? as timezone, ? as seconds"), " union "),
			"FeedIDPlaceholders": strings.Join(utilfuncs.ArrayWithValue(len(queryFeedIDs), "?"), ","),
		},
	); err != nil {
		return nil, err
	} else if err := queryToSlice(DB, query, params, &r); err != nil {
		return nil, err
	} else {
		return &r, nil
	}
}
